<div id="data_sources_selector">
    <div class="panel panel-default">
        {% include 'core_explore_common_app/user/selector/local_selector.html' with default=True %}
    </div>
    <div class="hidden" id="query_id">{{data.query_id}}</div>
</div>