{% extends 'core_main_app/_render/admin/theme/tools/box.html' %}

{% block box_title %}Select a search operator which match with the periodic element type path{% endblock %}

{% block box_body %}
    <form action="" method="post">
        {% csrf_token %}
        {{ data.associated_form }}
        <button type="submit" class="btn btn-default pull-right"><i class="fas fa-save"></i> Save</button>
    </form>
{% endblock %}
